@@ -105,7 +105,11 @@ bool CacheReader::parse( const QString& file )
 
 QSet<QString> CacheReader::documents() const
 {
+#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
   return QSet<QString>::fromList( mRanges.uniqueKeys() );
+#else
+  return QSet<QString>( mRanges.keyBegin(), mRanges.keyEnd() );
+#endif
 }
 
 QByteArray CacheReader::document( const QString& id ) const
